// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIpKQYJKoZIhvcNAQcCoIIpGjCCKRYCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg30MIIGcjCCBFqgAwIBAgITMwAAA9LaGRZdbcdJrwAA
// SIG // AAAD0jANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTI0MDIyMjIwMjU1MloX
// SIG // DTI1MDIxOTIwMjU1MlowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBALdqEoU6W4QYwAex/MdHkWVW
// SIG // /KE4Upt5VCyXOoFKiGCkfI4P9VCd0wiGQxD+WK6yL+Eo
// SIG // j/RxpFOy4Q4t/WbiJezoULDKavmxTNRp3z0ZkJfGR5ks
// SIG // YBoM0MItIeAfbqxMuoW6w0q5HncCxJi0x9MJWuhLiQZK
// SIG // VJdlY3Qixxa/PVmBY9PbzPanBhTthMeH03ScbieAeDJc
// SIG // TIbWIyxWrIlawZIwgkkK3bVuJe+tqbNIPKmRSmQWGeDA
// SIG // zkeTzFEehK2YPzHlBleu8yp1Z0a7yecNWh3wl4uxyG62
// SIG // 6YBQQ42xcFhreA5q2VBEgl0nlF24Fa2JVvIDH8Tl2Rtr
// SIG // 3ALpefWetYHsrQd3/JS02w7GR2FKsP0iSlgSbabJCV6B
// SIG // ILmGx/WltmTKxFZw5nuhDaNFkBq4UqEBMRAVEVY8rJ29
// SIG // FgqZjTs5YCTGm+YkjSeRciM+QYahAc6WhaXUCZ0hlWCy
// SIG // WYSc7gg4NbvH02eHPUfgo3UAWkxQGRnL1QG2Gn6XSwju
// SIG // FGud6wIDAQABo4IBgjCCAX4wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFANWxir0
// SIG // XadzyHYXZDqQCRDCKO8/MFQGA1UdEQRNMEukSTBHMS0w
// SIG // KwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRp
// SIG // b25zIExpbWl0ZWQxFjAUBgNVBAUTDTQ2NDIyMys1MDIw
// SIG // ODUwHwYDVR0jBBgwFoAUSG5k5VAF04KqFzc3IrVtqMp1
// SIG // ApUwVAYDVR0fBE0wSzBJoEegRYZDaHR0cDovL3d3dy5t
// SIG // aWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNybDBhBggrBgEFBQcB
// SIG // AQRVMFMwUQYIKwYBBQUHMAKGRWh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNydDAMBgNVHRMBAf8E
// SIG // AjAAMA0GCSqGSIb3DQEBDAUAA4ICAQClGvcxkigIlw60
// SIG // wWETAB6g+IEscqetgjSH9ndL4Po9vCpGs1Vyzl9Fsa0U
// SIG // 3dUv7kC2DsBSAHvQzF3k0hOdwnvLurkzCYwX8T26TacP
// SIG // UgDTy8IbuNBT+cof4Aj9mnuXk3hkbx/Btha9NGqrHBB/
// SIG // rwEz2Fob1WtCst4VsBFsPnfl0BQ+79IktYTB6HVdZy1p
// SIG // BsIQ1/G2cT3NQwMfbVV/L2Svk9NWPqY+xsfG9LkqbTN0
// SIG // VPme18Xuu5mfjtgO7CgR0OtrenSOiQjcPK8f1DukpddH
// SIG // R/0vzOohFqTtbFs1gF//N3E4K0DFD3vAJAQt6ZXYyCSq
// SIG // +j6uiEZ2Tws6KT1fgqD+RhG04iNTGeG0McH2jXpcDj8o
// SIG // 5hTt971pQq0Qfn1ysPHdCcTaP7pzlvXDHnYmVfgf8Ism
// SIG // p+nfZlgcdUB11k4PVDRkniap54Hdodi8n7bwnKXa2Fjb
// SIG // GrZg7Yy6c5uQHcqG8WZtnMXgwPcZDEAKhqPyE7iMtJrU
// SIG // YVtlsQrP9uPcXi9E7nAFcVJmt1g50MrOmuXfAR6x9TRP
// SIG // c7rpiVQQA15bEBNRGAxvFwzPh8pjRZjXJz7Sj+8JDyJ1
// SIG // WOGejwkUVdgg/bPjz+dX8KQmozKzF/Vd6Npa/vxhF4RS
// SIG // DOfhfbsJbSaYeMjlO7U1lOe51nq4n3BOWFJNnUFMZB4M
// SIG // Fl3zJVHkKzCCB3owggVioAMCAQICCmEOkNIAAAAAAAMw
// SIG // DQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRp
// SIG // ZmljYXRlIEF1dGhvcml0eSAyMDExMB4XDTExMDcwODIw
// SIG // NTkwOVoXDTI2MDcwODIxMDkwOVowfjELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEoMCYGA1UEAxMfTWljcm9zb2Z0IENvZGUg
// SIG // U2lnbmluZyBQQ0EgMjAxMTCCAiIwDQYJKoZIhvcNAQEB
// SIG // BQADggIPADCCAgoCggIBAKvw+nIQHC6t2G6qghBNNLry
// SIG // tlghn0IbKmvpWlCquAY4GgRJun/DDB7dN2vGEtgL8DjC
// SIG // mQawyDnVARQxQtOJDXlkh36UYCRsr55JnOloXtLfm1Oy
// SIG // CizDr9mpK656Ca/XllnKYBoF6WZ26DJSJhIv56sIUM+z
// SIG // RLdd2MQuA3WraPPLbfM6XKEW9Ea64DhkrG5kNXimoGMP
// SIG // LdNAk/jj3gcN1Vx5pUkp5w2+oBN3vpQ97/vjK1oQH01W
// SIG // KKJ6cuASOrdJXtjt7UORg9l7snuGG9k+sYxd6IlPhBry
// SIG // oS9Z5JA7La4zWMW3Pv4y07MDPbGyr5I4ftKdgCz1TlaR
// SIG // ITUlwzluZH9TupwPrRkjhMv0ugOGjfdf8NBSv4yUh7zA
// SIG // IXQlXxgotswnKDglmDlKNs98sZKuHCOnqWbsYR9q4ShJ
// SIG // nV+I4iVd0yFLPlLEtVc/JAPw0XpbL9Uj43BdD1FGd7P4
// SIG // AOG8rAKCX9vAFbO9G9RVS+c5oQ/pI0m8GLhEfEXkwcNy
// SIG // euBy5yTfv0aZxe/CHFfbg43sTUkwp6uO3+xbn6/83bBm
// SIG // 4sGXgXvt1u1L50kppxMopqd9Z4DmimJ4X7IvhNdXnFy/
// SIG // dygo8e1twyiPLI9AN0/B4YVEicQJTMXUpUMvdJX3bvh4
// SIG // IFgsE11glZo+TzOE2rCIF96eTvSWsLxGoGyY0uDWiIwL
// SIG // AgMBAAGjggHtMIIB6TAQBgkrBgEEAYI3FQEEAwIBADAd
// SIG // BgNVHQ4EFgQUSG5k5VAF04KqFzc3IrVtqMp1ApUwGQYJ
// SIG // KwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQD
// SIG // AgGGMA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU
// SIG // ci06AjGQQ7kUBU7h6qfHMdEjiTQwWgYDVR0fBFMwUTBP
// SIG // oE2gS4ZJaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0MjAxMV8y
// SIG // MDExXzAzXzIyLmNybDBeBggrBgEFBQcBAQRSMFAwTgYI
// SIG // KwYBBQUHMAKGQmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0MjAxMV8yMDEx
// SIG // XzAzXzIyLmNydDCBnwYDVR0gBIGXMIGUMIGRBgkrBgEE
// SIG // AYI3LgMwgYMwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cu
// SIG // bWljcm9zb2Z0LmNvbS9wa2lvcHMvZG9jcy9wcmltYXJ5
// SIG // Y3BzLmh0bTBABggrBgEFBQcCAjA0HjIgHQBMAGUAZwBh
// SIG // AGwAXwBwAG8AbABpAGMAeQBfAHMAdABhAHQAZQBtAGUA
// SIG // bgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAZ/KGpZjg
// SIG // VHkaLtPYdGcimwuWEeFjkplCln3SeQyQwWVfLiw++MNy
// SIG // 0W2D/r4/6ArKO79HqaPzadtjvyI1pZddZYSQfYtGUFXY
// SIG // DJJ80hpLHPM8QotS0LD9a+M+By4pm+Y9G6XUtR13lDni
// SIG // 6WTJRD14eiPzE32mkHSDjfTLJgJGKsKKELukqQUMm+1o
// SIG // +mgulaAqPyprWEljHwlpblqYluSD9MCP80Yr3vw70L01
// SIG // 724lruWvJ+3Q3fMOr5kol5hNDj0L8giJ1h/DMhji8MUt
// SIG // zluetEk5CsYKwsatruWy2dsViFFFWDgycScaf7H0J/je
// SIG // LDogaZiyWYlobm+nt3TDQAUGpgEqKD6CPxNNZgvAs031
// SIG // 4Y9/HG8VfUWnduVAKmWjw11SYobDHWM2l4bf2vP48hah
// SIG // mifhzaWX0O5dY0HjWwechz4GdwbRBrF1HxS+YWG18NzG
// SIG // GwS+30HHDiju3mUv7Jf2oVyW2ADWoUa9WfOXpQlLSBCZ
// SIG // gB/QACnFsZulP0V3HjXG0qKin3p6IvpIlR+r+0cjgPWe
// SIG // +L9rt0uX4ut1eBrs6jeZeRhL/9azI2h15q/6/IvrC4Dq
// SIG // aTuv/DDtBEyO3991bWORPdGdVk5Pv4BXIqF4ETIheu9B
// SIG // CrE/+6jMpF3BoYibV3FWTkhFwELJm3ZbCoBIa/15n8G9
// SIG // bW1qyVJzEw16UM0xghqNMIIaiQIBATCBlTB+MQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
// SIG // Q29kZSBTaWduaW5nIFBDQSAyMDExAhMzAAAD0toZFl1t
// SIG // x0mvAAAAAAPSMA0GCWCGSAFlAwQCAQUAoIGuMBkGCSqG
// SIG // SIb3DQEJAzEMBgorBgEEAYI3AgEEMBwGCisGAQQBgjcC
// SIG // AQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEi
// SIG // BCCk0LbOeo0Jl3UzqyYcR3jw0T+iGBzKrXSBXSbuitil
// SIG // gzBCBgorBgEEAYI3AgEMMTQwMqAUgBIATQBpAGMAcgBv
// SIG // AHMAbwBmAHShGoAYaHR0cDovL3d3dy5taWNyb3NvZnQu
// SIG // Y29tMA0GCSqGSIb3DQEBAQUABIIBgCc48pJFoQg+HKCK
// SIG // GchjBvpZi3JuKClRrODLGQPml2QVngSpiePaRjBMHSeO
// SIG // PLgCMOfCgBAX4vzTxVUyX5TMu8uGZu2ltL4PGFK8DyPz
// SIG // 4opT6XUPLHZFcDEzvbet3qy2q4J1HhDwca/2p18XhHJo
// SIG // eLSt4A/XJHmWDh2JaFAtiicG9OBY1Kp0a5wom6+YROVm
// SIG // KbFrdHORLl0/XhKl5iVLNAJ8bs+4jByJ5p+2k2jrDI2V
// SIG // EFEJbYwLQyGJKBdDwY9v9e4IxUoBNxfUHXD+yCmh9ttp
// SIG // /GlPXNiHGBFaguxP8EdZPkGecNoAw437Qo4v00hWG0BB
// SIG // NLU6vWAXhB766VneWzp2GUs8fmzDZqxfwh0HX2i1U6m2
// SIG // FY9LWbEAWBvPuC1+L3YQxpClScgPzxyQNXQBZnsJ0nda
// SIG // WFnl688pffxETfXdGolWJRmOht3+8RYs4/iOaKK7ViPt
// SIG // NU83xG2gIQmpBQqyGEqZ7mP/jHIPQkHlbzVXwCj5KBU9
// SIG // 2RBd4sE7JQEDFaGCF5cwgheTBgorBgEEAYI3AwMBMYIX
// SIG // gzCCF38GCSqGSIb3DQEHAqCCF3AwghdsAgEDMQ8wDQYJ
// SIG // YIZIAWUDBAIBBQAwggFSBgsqhkiG9w0BCRABBKCCAUEE
// SIG // ggE9MIIBOQIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
// SIG // AwQCAQUABCAnFpJdYLu3Zs2YupuXsQ7jankrJbgMLKFx
// SIG // OJqUb3kM9QIGZkYiunRpGBMyMDI0MDUyMjAzNTgyOC4z
// SIG // MDNaMASAAgH0oIHRpIHOMIHLMQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBP
// SIG // cGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxkIFRTUyBF
// SIG // U046N0YwMC0wNUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jv
// SIG // c29mdCBUaW1lLVN0YW1wIFNlcnZpY2WgghHtMIIHIDCC
// SIG // BQigAwIBAgITMwAAAfAqfB1ZO+YfrQABAAAB8DANBgkq
// SIG // hkiG9w0BAQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
// SIG // JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
// SIG // MjAxMDAeFw0yMzEyMDYxODQ1NTFaFw0yNTAzMDUxODQ1
// SIG // NTFaMIHLMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
// SIG // aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
// SIG // ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQL
// SIG // ExxNaWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMScw
// SIG // JQYDVQQLEx5uU2hpZWxkIFRTUyBFU046N0YwMC0wNUUw
// SIG // LUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0
// SIG // YW1wIFNlcnZpY2UwggIiMA0GCSqGSIb3DQEBAQUAA4IC
// SIG // DwAwggIKAoICAQC1Hi1Tozh3O0czE8xfRnrymlJNCaGW
// SIG // ommPy0eINf+4EJr7rf8tSzlgE8Il4Zj48T5fTTOAh6nI
// SIG // TRf2lK7+upcnZ/xg0AKoDYpBQOWrL9ObFShylIHfr/DQ
// SIG // 4PsRX8GRtInuJsMkwSg63bfB4Q2UikMEP/CtZHi8xW5X
// SIG // tAKp95cs3mvUCMvIAA83Jr/UyADACJXVU4maYisczUz7
// SIG // J111eD1KrG9mQ+ITgnRR/X2xTDMCz+io8ZZFHGwEZg+c
// SIG // 3vmPp87m4OqOKWyhcqMUupPveO/gQC9Rv4szLNGDaoeP
// SIG // eK6IU0JqcGjXqxbcEoS/s1hCgPd7Ux6YWeWrUXaxbb+J
// SIG // osgOazUgUGs1aqpnLjz0YKfUqn8i5TbmR1dqElR4QA+O
// SIG // ZfeVhpTonrM4sE/MlJ1JLpR2FwAIHUeMfotXNQiytYfR
// SIG // BUOJHFeJYEflZgVk0Xx/4kZBdzgFQPOWfVd2NozXlC2e
// SIG // pGtUjaluA2osOvQHZzGOoKTvWUPX99MssGObO0xJHd0D
// SIG // ygP/JAVp+bRGJqa2u7AqLm2+tAT26yI5veccDmNZsg3v
// SIG // Dh1HcpCJa9QpRW/MD3a+AF2ygV1sRnGVUVG3VODX3BhG
// SIG // T8TMU/GiUy3h7ClXOxmZ+weCuIOzCkTDbK5OlAS8qSPp
// SIG // gp+XGlOLEPaM31Mgf6YTppAaeP0ophx345ohtwIDAQAB
// SIG // o4IBSTCCAUUwHQYDVR0OBBYEFNCCsqdXRy/MmjZGVTAv
// SIG // x7YFWpslMB8GA1UdIwQYMBaAFJ+nFV0AXmJdg/Tl0mWn
// SIG // G1M1GelyMF8GA1UdHwRYMFYwVKBSoFCGTmh0dHA6Ly93
// SIG // d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jv
// SIG // c29mdCUyMFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEp
// SIG // LmNybDBsBggrBgEFBQcBAQRgMF4wXAYIKwYBBQUHMAKG
// SIG // UGh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMv
// SIG // Y2VydHMvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBD
// SIG // QSUyMDIwMTAoMSkuY3J0MAwGA1UdEwEB/wQCMAAwFgYD
// SIG // VR0lAQH/BAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/BAQD
// SIG // AgeAMA0GCSqGSIb3DQEBCwUAA4ICAQA4IvSbnr4jEPgo
// SIG // 5W4xj3/+0dCGwsz863QGZ2mB9Z4SwtGGLMvwfsRUs3NI
// SIG // lPD/LsWAxdVYHklAzwLTwQ5M+PRdy92DGftyEOGMHfut
// SIG // 7Gq8L3RUcvrvr0AL/NNtfEpbAEkCFzseextY5s3hzj3r
// SIG // X2wvoBZm2ythwcLeZmMgHQCmjZp/20fHWJgrjPYjse6R
// SIG // DJtUTlvUsjr+878/t+vrQEIqlmebCeEi+VQVxc7wF0Lu
// SIG // MTw/gCWdcqHoqL52JotxKzY8jZSQ7ccNHhC4eHGFRpaK
// SIG // eiSQ0GXtlbGIbP4kW1O3JzlKjfwG62NCSvfmM1iPD90X
// SIG // YiFm7/8mgR16AmqefDsfjBCWwf3qheIMfgZzWqeEz8la
// SIG // FmM8DdkXjuOCQE/2L0TxhrjUtdMkATfXdZjYRlscBDyr
// SIG // 8zGMlprFC7LcxqCXlhxhtd2CM+mpcTc8RB2D3Eor0Udo
// SIG // P36Q9r4XWCVV/2Kn0AXtvWxvIfyOFm5aLl0eEzkhfv/X
// SIG // mUlBeOCElS7jdddWpBlQjJuHHUHjOVGXlrJT7X4hicF1
// SIG // o23x5U+j7qPKBceryP2/1oxfmHc6uBXlXBKukV/QCZBV
// SIG // AiBMYJhnktakWHpo9uIeSnYT6Qx7wf2RauYHIER8SLRm
// SIG // blMzPOs+JHQzrvh7xStx310LOp+0DaOXs8xjZvhpn+Wu
// SIG // Zij5RmZijDCCB3EwggVZoAMCAQICEzMAAAAVxedrngKb
// SIG // SZkAAAAAABUwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNV
// SIG // BAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYD
// SIG // VQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
// SIG // Q29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBS
// SIG // b290IENlcnRpZmljYXRlIEF1dGhvcml0eSAyMDEwMB4X
// SIG // DTIxMDkzMDE4MjIyNVoXDTMwMDkzMDE4MzIyNVowfDEL
// SIG // MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
// SIG // EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
// SIG // c29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9z
// SIG // b2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwggIiMA0GCSqG
// SIG // SIb3DQEBAQUAA4ICDwAwggIKAoICAQDk4aZM57RyIQt5
// SIG // osvXJHm9DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25
// SIG // PhdgM/9cT8dm95VTcVrifkpa/rg2Z4VGIwy1jRPPdzLA
// SIG // EBjoYH1qUoNEt6aORmsHFPPFdvWGUNzBRMhxXFExN6AK
// SIG // OG6N7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6
// SIG // GnszrYBbfowQHJ1S/rboYiXcag/PXfT+jlPP1uyFVk3v
// SIG // 3byNpOORj7I5LFGc6XBpDco2LXCOMcg1KL3jtIckw+DJ
// SIG // j361VI/c+gVVmG1oO5pGve2krnopN6zL64NF50ZuyjLV
// SIG // wIYwXE8s4mKyzbnijYjklqwBSru+cakXW2dg3viSkR4d
// SIG // Pf0gz3N9QZpGdc3EXzTdEonW/aUgfX782Z5F37ZyL9t9
// SIG // X4C626p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0lBw0gg/w
// SIG // EPK3Rxjtp+iZfD9M269ewvPV2HM9Q07BMzlMjgK8Qmgu
// SIG // EOqEUUbi0b1qGFphAXPKZ6Je1yh2AuIzGHLXpyDwwvoS
// SIG // CtdjbwzJNmSLW6CmgyFdXzB0kZSU2LlQ+QuJYfM2BjUY
// SIG // hEfb3BvR/bLUHMVr9lxSUV0S2yW6r1AFemzFER1y7435
// SIG // UsSFF5PAPBXbGjfHCBUYP3irRbb1Hode2o+eFnJpxq57
// SIG // t7c+auIurQIDAQABo4IB3TCCAdkwEgYJKwYBBAGCNxUB
// SIG // BAUCAwEAATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6C
// SIG // kTxGNSnPEP8vBO4wHQYDVR0OBBYEFJ+nFV0AXmJdg/Tl
// SIG // 0mWnG1M1GelyMFwGA1UdIARVMFMwUQYMKwYBBAGCN0yD
// SIG // fQEBMEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBvc2l0b3J5
// SIG // Lmh0bTATBgNVHSUEDDAKBggrBgEFBQcDCDAZBgkrBgEE
// SIG // AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYw
// SIG // DwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbL
// SIG // j+iiXGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBNMEugSaBH
// SIG // hkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
// SIG // bC9wcm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0y
// SIG // My5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUFBzAC
// SIG // hj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2Nl
// SIG // cnRzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDAN
// SIG // BgkqhkiG9w0BAQsFAAOCAgEAnVV9/Cqt4SwfZwExJFvh
// SIG // nnJL/Klv6lwUtj5OR2R4sQaTlz0xM7U518JxNj/aZGx8
// SIG // 0HU5bbsPMeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYu
// SIG // nKmCVgADsAW+iehp4LoJ7nvfam++Kctu2D9IdQHZGN5t
// SIG // ggz1bSNU5HhTdSRXud2f8449xvNo32X2pFaq95W2KFUn
// SIG // 0CS9QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wM
// SIG // nosZiefwC2qBwoEZQhlSdYo2wh3DYXMuLGt7bj8sCXgU
// SIG // 6ZGyqVvfSaN0DLzskYDSPeZKPmY7T7uG+jIa2Zb0j/aR
// SIG // AfbOxnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2dY3RI
// SIG // LLFORy3BFARxv2T5JL5zbcqOCb2zAVdJVGTZc9d/HltE
// SIG // AY5aGZFrDZ+kKNxnGSgkujhLmm77IVRrakURR6nxt67I
// SIG // 6IleT53S0Ex2tVdUCbFpAUR+fKFhbHP+CrvsQWY9af3L
// SIG // wUFJfn6Tvsv4O+S3Fb+0zj6lMVGEvL8CwYKiexcdFYmN
// SIG // cP7ntdAoGokLjzbaukz5m/8K6TT4JDVnK+ANuOaMmdbh
// SIG // IurwJ0I9JZTmdHRbatGePu1+oDEzfbzL6Xu/OHBE0ZDx
// SIG // yKs6ijoIYn/ZcGNTTY3ugm2lBRDBcQZqELQdVTNYs6Fw
// SIG // ZvKhggNQMIICOAIBATCB+aGB0aSBzjCByzELMAkGA1UE
// SIG // BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNV
// SIG // BAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBD
// SIG // b3Jwb3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFt
// SIG // ZXJpY2EgT3BlcmF0aW9uczEnMCUGA1UECxMeblNoaWVs
// SIG // ZCBUU1MgRVNOOjdGMDAtMDVFMC1EOTQ3MSUwIwYDVQQD
// SIG // ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloiMK
// SIG // AQEwBwYFKw4DAhoDFQDCKAZKKv5lsdC2yoMGKYiQy79p
// SIG // /6CBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
// SIG // EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
// SIG // HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAk
// SIG // BgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAy
// SIG // MDEwMA0GCSqGSIb3DQEBCwUAAgUA6ffhHDAiGA8yMDI0
// SIG // MDUyMjAzMTIyOFoYDzIwMjQwNTIzMDMxMjI4WjB3MD0G
// SIG // CisGAQQBhFkKBAExLzAtMAoCBQDp9+EcAgEAMAoCAQAC
// SIG // AhAxAgH/MAcCAQACAhPDMAoCBQDp+TKcAgEAMDYGCisG
// SIG // AQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwKgCjAIAgEA
// SIG // AgMHoSChCjAIAgEAAgMBhqAwDQYJKoZIhvcNAQELBQAD
// SIG // ggEBAI01+BzjK6m6fMCbqt/I7EuycnNCzI8e9bU28Oh6
// SIG // zqSJGhp7EP+LzmbedX8Q4VIAUCKefLEdhdOe0ukIlMt4
// SIG // IkWr/uvVeSCQHhUr+q2Mj8590yWFw6h5k6m+j9/O0UQr
// SIG // o8edaPIjlbOwaEjUvcQEESsgZ/lfYxdS57fTua09EIQW
// SIG // Xyf1whQduJFZr0sn15p6j1TnZjqRmq3eMHIGJk+9Bk/H
// SIG // bM+425rOJx9WYEfkyGnhO4LepxZ5pDpSHkoHWdJRFlE2
// SIG // As4hmM9vxSefb76nrAlYEo4+1INBaofUandSWiWfaCeW
// SIG // TYDCLPTdF6lEWRg4LFXHu9zKeoqxHcpaYECSHoQxggQN
// SIG // MIIECQIBATCBkzB8MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
// SIG // JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
// SIG // MjAxMAITMwAAAfAqfB1ZO+YfrQABAAAB8DANBglghkgB
// SIG // ZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3
// SIG // DQEJEAEEMC8GCSqGSIb3DQEJBDEiBCCQQ80hS0xr1I50
// SIG // ocT39INPxl9DquqfuaYK3cliozoPLTCB+gYLKoZIhvcN
// SIG // AQkQAi8xgeowgecwgeQwgb0EIFwBmqOlcv3kU7mAB5sW
// SIG // R74QFAiS6mb+CM6asnFAZUuLMIGYMIGApH4wfDELMAkG
// SIG // A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
// SIG // BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
// SIG // dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0
// SIG // IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAHwKnwdWTvm
// SIG // H60AAQAAAfAwIgQgb+BaCIxpiCjPYK2i6rvoNXoe5Vrg
// SIG // Hhr1xWNc0LmuquEwDQYJKoZIhvcNAQELBQAEggIAPHVK
// SIG // dnOj24PMuuSrRlykzRn2fkZGM2xKEt66VPkJTBj95i8w
// SIG // FbtKq2TX9zitTmzzegZhi1PgrJb6tSrpl0cM1wGH9Fm2
// SIG // P9NfgPwUdnqn5YAUsEduG3cJ3r/Nee2RUv/7SUz2pvjm
// SIG // i2Hq4iASqBhBXoYiTljTshCk7MHyha00OMCY7nb4TufL
// SIG // PJpWyZSHCOP9JQ21mW0SRkhH5BqkiZIFUUrvOl04QNJC
// SIG // xQG0VfbzGyRlaavzEQV5qAMys240aRCou89AKdNp23qR
// SIG // +kZDRLdQYerU/HHzxdVK81Flsw0QRQNXJeURVeDSK88e
// SIG // EgFMOUKNhtEInJUJPYPX/M/KShCdOEzCtjit24ztu3Kt
// SIG // rgRf9CLXcjz6EbmkirgTFzgxOvJZKJch2b9QP0qaGWNu
// SIG // tQdWK4ECmy8ZLR81pXJGSuLVozyLTeleoCqZxluNs2YV
// SIG // DWor5/rveqdPKw58TtVKOYHa9AxGzjcmXeRn+XqXmNk9
// SIG // 2lJ77swMEERusngmHLaDfLPdUZ+R/jDmzwjpV4O7dejQ
// SIG // VhcLO3tbZlcc3JGHHsG19PxgH9idwVWKvANBFUY3RkVr
// SIG // 05P0wVefz8g0KPUY7jq47u9e3/hBMihOYBcSpzMiK1XS
// SIG // 25LngiZraYfvyfJLHFfjk4S/FeJ6oWQuRFnvm4J8N9GV
// SIG // 3TD3v18M/cJM/8aQphM=
// SIG // End signature block
